@@ -237,7 +237,7 @@ if __name__ == '__main__':
     sys.exit(app.exec_())
 else:
     print(f'[{time.ctime()}][main/Info] now varbile "__name__"={__name__},run in web mode')
-    run('v1.0')
+    run('v1.0.4')
 
 
 
